Module tl

Module tl 

Core TL schema types: definitions, parameters, types, flags, and categories.

Structs

Definition
A single TL definition: either a constructor or a function.
Flag
A conditional-field flag reference: the flags field name and the bit index.
Parameter
A single name:Type parameter inside a TL definition.
Type
The type of a definition or a parameter, e.g. ns.Vector<!X>.

Enums

Category
Whether a TL definition is a data constructor or an RPC function.
ParameterType
The kind of a single TL parameter.